@@ -15,3 +15,10 @@
 #' @format A data set with 254 observations of 3 variables.
 #' @source See Mike Bostock \url{http://bl.ocks.org/mbostock/4062045}.
 "MisLinks"
+
+#' Edge list of REF (2014) journal submissions for Politics and International
+#' Relations
+#' 
+#' @format A data set with 2732 rows and 3 variables.
+#' @source See REF 2014 \url{http://results.ref.ac.uk/DownloadSubmissions/ByUoa/21}.
+"SchoolsJournals"
